@@ -432,6 +432,36 @@ def store_credentials(opts: ProxyContext, client: CumulocityClient):
         opts.show_info(f"Env file is already up to date: {opts.env_file}")
 
 
+def _extract_config_id(matching_config) -> str:
+    logging.info(
+        'Using Configuration with Name "%s" and Remote Port %s',
+        matching_config.get("name"),
+        matching_config.get("port"),
+    )
+    return matching_config.get("id")
+
+
+def _guess_config(configs) -> str:
+    # If user has not provide the config, then we can try guessing
+    if len(configs) == 1:
+        return _extract_config_id(configs[0])
+
+    # Use first match which uses port 22
+    configs_using_ssh_port = [c for c in configs if c.get("port", 0) == 22]
+    if configs_using_ssh_port:
+        return _extract_config_id(configs_using_ssh_port[0])
+
+    # Use first match with ssh in its name
+    configs_with_ssh_name = [
+        c for c in configs if "ssh" in str(c.get("name", "")).lower()
+    ]
+    if configs_with_ssh_name:
+        return _extract_config_id(configs_with_ssh_name[0])
+
+    # fallback to first config
+    return _extract_config_id(configs[0])
+
+
 def get_config_id(ctx: click.Context, mor: Dict[str, Any], config: str) -> str:
     """Get the remote access configuration id matching a specific type
     from a device managed object
@@ -466,17 +496,9 @@ def get_config_id(ctx: click.Context, mor: Dict[str, Any], config: str) -> str:
         )
         ctx.exit(ExitCodes.DEVICE_NO_PASSTHROUGH_CONFIG)
 
-    def extract_config_id(matching_config):
-        logging.info(
-            'Using Configuration with Name "%s" and Remote Port %s',
-            matching_config.get("name"),
-            matching_config.get("port"),
-        )
-        return matching_config.get("id")
-
     if not config:
-        # use first config
-        return extract_config_id(valid_configs[0])
+        # If user has not provide the config, then we can try guessing
+        return _guess_config(valid_configs)
 
     # find config matching name
     matches = [
@@ -486,17 +508,17 @@ def get_config_id(ctx: click.Context, mor: Dict[str, Any], config: str) -> str:
     ]
 
     if matches:
-        return extract_config_id(matches[0])
+        return _extract_config_id(matches[0])
 
     if valid_configs:
-        # Fallback to using the first valid config (if not matches names were found)
+        # Fallback to guessing if not matches names were found
         logging.warning(
             "No matching %s configs found (name=%s), so falling back to first config (name=%s)",
             PASSTHROUGH,
             config,
             valid_configs[0].get("name", ""),
         )
-        return extract_config_id(valid_configs[0])
+        return _guess_config(valid_configs)
 
     # Technically it should never reach here, however leave in place in
     # case the above logic is changed
@@ -507,6 +529,7 @@ def get_config_id(ctx: click.Context, mor: Dict[str, Any], config: str) -> str:
         PASSTHROUGH,
     )
     ctx.exit(ExitCodes.DEVICE_NO_MATCHING_PASSTHROUGH_CONFIG)
+    return None
 
 
 def run_proxy_in_background(
@@ -658,6 +681,7 @@ def start_proxy(
 
     try:
         if opts.socket_path:
+            # pylint: disable=used-before-assignment
             socket_server = UnixStreamProxyServer(
                 opts.socket_path,
                 WebsocketClient(**client_opts),
